@@ -3,6 +3,7 @@ from .singleton_decorator import singleton
 from .page_id_utils import format_uuid
 from .fuzzy_matcher import FuzzyMatcher
 from .factory_decorator import factory_only
+from .singleton_metaclass import SingletonMetaClass
 
 __all__ = [
     "LoggingMixin",
@@ -11,4 +12,5 @@ __all__ = [
     "FuzzyMatcher",
     "factory_only",
     "singleton",
+    "SingletonMetaClass",
 ]
